@@ -1,8 +1,5 @@
 #!/bin/bash -xe
 # script to get tarball(s) from Jenkins
-
-KAMEL_VERSION="1.3.1" # see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/master/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
-
 scratchFlag=""
 JOB_BRANCH=""
 doRhpkgContainerBuild=1
@@ -34,6 +31,11 @@ fi
 
 UPSTREAM_JOB_NAME="crw-deprecated_${JOB_BRANCH}" # eg., 2.6
 
+# see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/crw-2-rhel-8/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
+KAMEL_BUILDSH="https://github.com/redhat-developer/codeready-workspaces-deprecated/raw/$(git rev-parse --abbrev-ref HEAD)/kamel/build.sh"
+KAMEL_VERSION="$(curl -sSLo- ${KAMEL_BUILDSH} | grep "export KAMEL_VERSION" | sed -r -e 's#.+KAMEL_VERSION="(.+)"#\1#')"
+echo "Using KAMEL_VERSION = ${KAMEL_VERSION} from ${KAMEL_BUILDSH}"
+
 jenkinsURL=""
 checkJenkinsURL() {
 	checkURL="$1"
